==> org-lsst-ccs-image-utilities-3.1.20-20241115.185551-1-sources.jar: org/lsst/ccs/utilities/image/DateUtils.java <==
package org.lsst.ccs.utilities.image;

import java.time.Instant;
import java.util.Date;
import nom.tam.fits.FitsDate;
import nom.tam.fits.FitsException;
import org.lsst.ccs.utilities.taitime.CCSTimeStamp;

/**
 * Utilities for dealing with Dates/Times.
 *
 * @author tonyj
 */
public class DateUtils {

    private DateUtils() {
    }

    private static Date convertTemporalToDate(Object temporalObject) {
        if (temporalObject instanceof Date) {
            return (Date) temporalObject;
        } else if (temporalObject instanceof Instant) {
            return Date.from((Instant) temporalObject);
        } else if (temporalObject instanceof CCSTimeStamp) {
            return Date.from(((CCSTimeStamp) temporalObject).getTAIInstant());
        } else {
            throw new IllegalArgumentException("Unsupported temporal class: " + temporalObject);
        }
    }

    public static double convertDateToMJD(Object temporalObject) {
        return convertDateToMJD(convertTemporalToDate(temporalObject));
    }

    public static String convertDateToString(Object temporalObject) {
        return convertDateToString(convertTemporalToDate(temporalObject));
    }

    /**
     * Convert a java.util.Date to a modified Julian date (MJD).
     *
     * @param date The date to convert
     * @return The date formatted as a modified Julian date
     */
    public static double convertDateToMJD(Date date) {
        return date.getTime() / 1000.0 / 86400.0 + 2440587.5 - 2_400_000.5;
    }

    /**
     * Convert date to a string following FITS standards.
     *
     * @param date The input date
     * @return The formatted date/time
     */
    static String convertDateToString(Date date) {
        return FitsDate.getFitsDateString(date);
    }

    /**
     * Convert string to a date following FITS standards.
     *
     * @param string The string to convert
     * @return The converted Date
     * @throws FitsException If the string is not in the correct format.
     */
    public static Date convertStringToDate(String string) throws FitsException {
        return new FitsDate(string).toDate();
    }
}

==> org-lsst-ccs-image-utilities-3.1.22-20250206.170726-2-sources.jar: org/lsst/ccs/utilities/image/DateUtils.java <==
package org.lsst.ccs.utilities.image;

import java.time.Instant;
import java.util.Date;
import nom.tam.fits.FitsDate;
import nom.tam.fits.FitsException;
import org.lsst.ccs.utilities.taitime.CCSTimeStamp;

/**
 * Utilities for dealing with Dates/Times.
 *
 * @author tonyj
 */
public class DateUtils {

    private DateUtils() {
    }

    /***
     * Note, using Date as the return type here limits us to ms precision, which
     * may not be sufficient in all cases (e.g. guider stamps).
     * @param temporalObject
     * @return 
     */
    private static Date convertTemporalToDate(Object temporalObject) {
        if (temporalObject instanceof Date) {
            return (Date) temporalObject;
        } else if (temporalObject instanceof Instant) {
            return Date.from((Instant) temporalObject);
        } else if (temporalObject instanceof CCSTimeStamp) {
            return Date.from(((CCSTimeStamp) temporalObject).getTAIInstant());
        } else {
            throw new IllegalArgumentException("Unsupported temporal class: " + temporalObject);
        }
    }

    public static double convertDateToMJD(Object temporalObject) {
        return convertDateToMJD(convertTemporalToDate(temporalObject));
    }

    public static String convertDateToString(Object temporalObject) {
        return convertDateToString(convertTemporalToDate(temporalObject));
    }

    /**
     * Convert a java.util.Date to a modified Julian date (MJD).
     *
     * @param date The date to convert
     * @return The date formatted as a modified Julian date
     */
    public static double convertDateToMJD(Date date) {
        return date.getTime() / 1000.0 / 86400.0 + 2440587.5 - 2_400_000.5;
    }

    /**
     * Convert date to a string following FITS standards.
     *
     * @param date The input date
     * @return The formatted date/time
     */
    static String convertDateToString(Date date) {
        return FitsDate.getFitsDateString(date);
    }

    /**
     * Convert string to a date following FITS standards.
     *
     * @param string The string to convert
     * @return The converted Date
     * @throws FitsException If the string is not in the correct format.
     */
    public static Date convertStringToDate(String string) throws FitsException {
        return new FitsDate(string).toDate();
    }
}
